@@ -1,5 +1,6 @@
 """Package for collecting ACS and geospatial data from the Census API."""
 
+from importlib.metadata import version
 import logging
 from logging import Logger, StreamHandler
 
@@ -7,11 +8,6 @@ from . import api, constants, errors, geography, query, socrata, utilities  # no
 from .query import Query  # noqa
 from .utilities import clear_cache  # noqa
 
-try:
-    from importlib.metadata import version
-except ImportError:  # pragma: no cover
-    from importlib_metadata import version  # type: ignore
-
 # Initialize version string from package metadata
 __version__ = version(__name__)
 
