@@ -18,7 +18,6 @@ from zipfile import BadZipFile
 
 import geopandas as gpd
 from geopandas.geodataframe import GeoDataFrame
-import numpy as np
 import pandas as pd
 from pandas import DataFrame
 from pkg_resources import resource_string
@@ -117,8 +116,8 @@ class Query:
         # Initialize invalid variables defaultdict
         self._invalid_variables: DefaultDict[int, list] = defaultdict(list)
 
-        # Create cache directory if it doesn't exist
-        CACHE_DIRECTORY_PATH.mkdir(exist_ok=True)
+        # Create cache directory, plus any enclosing directories, as needed
+        CACHE_DIRECTORY_PATH.mkdir(parents=True, exist_ok=True)
 
     def __repr__(self) -> str:  # pragma: no cover
         attributes = ['estimate', 'years', 'variables', 'for_geo', 'in_geo']
@@ -379,8 +378,9 @@ class Query:
         non_geo_names: set = set(dataframe.columns) - geo_names
         dataframe = dataframe.drop_duplicates(subset=non_geo_names, ignore_index=True)
 
-        # Insert NAs for annotated rows to avoid outlier values like -999,999,999
-        dataframe.loc[dataframe['annotation'].notnull(), 'value'] = np.NaN
+        # Insert NAs for annotated row values to avoid outlier values like -999,999,999
+        dataframe.loc[dataframe['annotation'].notnull(), 'value'] = ''
+        dataframe['value'] = pd.to_numeric(dataframe['value'], errors='coerce')
 
         # Create year date column
         dataframe['date'] = pd.to_datetime(
